Installation — CGDAT 2.0.3-3-g9aff488 documentation

# Installation

## Install using the python package index (PyPi)

OS X & Linux::

    pip install cgdat

Warning

This package was only tested on the windows operation system.

Windows::

    pip install cgdat

## Development setup

If you want to manually install the python package please fork from github and run the following commands:

    python setup.py build
    python setup.py develop
    python setup.py install